# hello

[![PyPI - Version](https://img.shields.io/pypi/v/rtd_init.svg)](https://pypi.org/project/rtd_init)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/hello.svg)](https://pypi.org/project/hello)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install hello
```

## License

`hello` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
